translate.tools.pogrep.GrepFilter

Package translate :: Package tools :: Module pogrep :: Class GrepFilter |
[hide private]
[frames] | no frames]

# Class GrepFilter

source code

Instance Methods | [hide private]
__init__(self, searchstring, searchparts, ignorecase=False, useregexp=False, invertmatch=False, accelchar=None, encoding='utf-8', max_matches=0) builds a checkfilter using the given checker | source code
matches(self, teststr) | source code
filterunit(self, unit) runs filters on an element | source code
filterfile(self, thefile) runs filters on a translation file object | source code
getmatches(self, units) | source code